@@ -7,7 +7,7 @@ import subprocess
 import os
 import sys
 
-from ipython_genutils.py3compat import which, cast_bytes_py2
+from ipython_genutils.py3compat import which, cast_bytes_py2, getcwd
 from traitlets import Integer, List, Bool, Instance, Unicode
 from testpath.tempdir import TemporaryWorkingDirectory
 from .latex import LatexExporter
@@ -27,6 +27,15 @@ class LatexFailed(IOError):
         u = self.__unicode__()
         return cast_bytes_py2(u)
 
+def prepend_to_env_search_path(varname, value, envdict):
+    """Add value to the environment variable varname in envdict
+
+    e.g. prepend_to_env_search_path('BIBINPUTS', '/home/sally/foo', os.environ)
+    """
+    if not value:
+        return  # Nothing to add
+
+    envdict[varname] = cast_bytes_py2(value) + os.pathsep + envdict.get(varname, '')
 
 class PDFExporter(LatexExporter):
     """Writer designed to write to PDF files.
@@ -35,6 +44,7 @@ class PDFExporter(LatexExporter):
     a temporary directory using the template machinery, and then runs LaTeX
     to create a pdf.
     """
+    export_from_notebook="pdf"
 
     latex_count = Integer(3,
         help="How many times latex will be called."
@@ -52,12 +62,8 @@ class PDFExporter(LatexExporter):
         help="Whether to display the output of latex commands."
     ).tag(config=True)
 
-    temp_file_exts = List(['.aux', '.bbl', '.blg', '.idx', '.log', '.out'],
-        help="File extensions of temp files to remove after running."
-    ).tag(config=True)
-    
     texinputs = Unicode(help="texinputs dir. A notebook's directory is added")
-    writer = Instance("nbconvert.writers.FilesWriter", args=())
+    writer = Instance("nbconvert.writers.FilesWriter", args=(), kw={'build_directory': '.'})
     
     _captured_output = List()
 
@@ -105,10 +111,10 @@ class PDFExporter(LatexExporter):
         if shell:
             command = subprocess.list2cmdline(command)
         env = os.environ.copy()
-        env['TEXINPUTS'] = os.pathsep.join([
-            cast_bytes_py2(self.texinputs),
-            env.get('TEXINPUTS', ''),
-        ])
+        prepend_to_env_search_path('TEXINPUTS', self.texinputs, env)
+        prepend_to_env_search_path('BIBINPUTS', self.texinputs, env)
+        prepend_to_env_search_path('BSTINPUTS', self.texinputs, env)
+
         with open(os.devnull, 'rb') as null:
             stdout = subprocess.PIPE if not self.verbose else None
             for index in range(count):
@@ -141,21 +147,11 @@ class PDFExporter(LatexExporter):
         filename = os.path.splitext(filename)[0]
 
         def log_error(command, out):
-            self.log.warn('%s had problems, most likely because there were no citations',
+            self.log.warning('%s had problems, most likely because there were no citations',
                 command[0])
             self.log.debug(u"%s output: %s\n%s", command[0], command, out)
 
         return self.run_command(self.bib_command, filename, 1, log_error)
-
-    def clean_temp_files(self, filename):
-        """Remove temporary files created by xelatex/bibtex."""
-        self.log.info("Removing temporary LaTeX files")
-        filename = os.path.splitext(filename)[0]
-        for ext in self.temp_file_exts:
-            try:
-                os.remove(filename+ext)
-            except OSError:
-                pass
     
     def from_notebook_node(self, nb, resources=None, **kw):
         latex, resources = super(PDFExporter, self).from_notebook_node(
@@ -165,7 +161,7 @@ class PDFExporter(LatexExporter):
         if resources and resources.get('metadata', {}).get('path'):
             self.texinputs = resources['metadata']['path']
         else:
-            self.texinputs = os.getcwd()
+            self.texinputs = getcwd()
         
         self._captured_outputs = []
         with TemporaryWorkingDirectory():
