@@ -11,17 +11,19 @@ import os
 import uuid
 import json
 
-from traitlets import HasTraits, Unicode, List, Dict, default, observe
+from traitlets import HasTraits, Unicode, List, Dict, Bool, default, observe
+from traitlets.config import Config
 from traitlets.utils.importstring import import_item
 from ipython_genutils import py3compat
 from jinja2 import (
-    TemplateNotFound, Environment, ChoiceLoader, FileSystemLoader, BaseLoader
+    TemplateNotFound, Environment, ChoiceLoader, FileSystemLoader, BaseLoader,
+    DictLoader
 )
 
 from nbconvert import filters
 from .exporter import Exporter
 
-#Jinja2 extensions to load.
+# Jinja2 extensions to load.
 JINJA_EXTENSIONS = ['jinja2.ext.loopcontrols']
 
 default_filters = {
@@ -56,7 +58,6 @@ default_filters = {
         'json_dumps': json.dumps,
 }
 
-
 class ExtensionTolerantLoader(BaseLoader):
     """A template loader which optionally adds a given extension when searching.
 
@@ -68,7 +69,6 @@ class ExtensionTolerantLoader(BaseLoader):
     def __init__(self, loader, extension):
         self.loader = loader
         self.extension = extension
-   
 
     def get_source(self, environment, template):
         try:
@@ -102,6 +102,8 @@ class TemplateExporter(Exporter):
 
     _template_cached = None
 
+    export_from_notebook = "custom"
+
     def _invalidate_template_cache(self, change=None):
         self._template_cached = None
 
@@ -123,11 +125,28 @@ class TemplateExporter(Exporter):
             self._environment_cached = self._create_environment()
         return self._environment_cached
 
+    @property
+    def default_config(self):
+        c = Config({
+            'RegexRemovePreprocessor': {
+                'enabled': True
+                },
+            'TagRemovePreprocessor': {
+                'enabled': True
+                }
+            })
+        c.merge(super(TemplateExporter, self).default_config)
+        return c
 
     template_file = Unicode(
             help="Name of the template file to use"
     ).tag(config=True, affects_template=True)
 
+    raw_template = Unicode('', help="raw template string").tag(affects_environment=True)
+
+    _last_template_file = ""
+    _raw_template_key = "<memory>"
+
     @observe('template_file')
     def _template_file_changed(self, change):
         new = change['new']
@@ -147,6 +166,12 @@ class TemplateExporter(Exporter):
     def _template_file_default(self):
         return self.default_template
 
+    @observe('raw_template')
+    def _raw_template_changed(self, change):
+        if not change['new']:
+            self.template_file = self.default_template or self._last_template_file
+        self._invalidate_template_cache()
+
     default_template = Unicode(u'').tag(affects_template=True)
 
     template_path = List(['.']).tag(config=True, affects_environment=True)
@@ -160,10 +185,42 @@ class TemplateExporter(Exporter):
         os.path.join("..", "templates", "skeleton"),
         help="Path where the template skeleton files are located.",
     ).tag(affects_environment=True)
-    
+
     #Extension that the template files use.
     template_extension = Unicode(".tpl").tag(config=True, affects_environment=True)
 
+    exclude_input = Bool(False,
+        help = "This allows you to exclude code cell inputs from all templates if set to True."
+        ).tag(config=True)
+
+    exclude_input_prompt = Bool(False,
+        help = "This allows you to exclude input prompts from all templates if set to True."
+        ).tag(config=True)
+
+    exclude_output = Bool(False,
+        help = "This allows you to exclude code cell outputs from all templates if set to True."
+        ).tag(config=True)
+
+    exclude_output_prompt = Bool(False,
+        help = "This allows you to exclude output prompts from all templates if set to True."
+        ).tag(config=True)
+
+    exclude_code_cell = Bool(False,
+        help = "This allows you to exclude code cells from all templates if set to True."
+        ).tag(config=True)
+
+    exclude_markdown = Bool(False,
+        help = "This allows you to exclude markdown cells from all templates if set to True."
+        ).tag(config=True)
+
+    exclude_raw = Bool(False,
+        help = "This allows you to exclude raw cells from all templates if set to True."
+        ).tag(config=True)
+
+    exclude_unknown = Bool(False,
+        help = "This allows you to exclude unknown cells from all templates if set to True."
+        ).tag(config=True)
+
     extra_loaders = List(
         help="Jinja loaders to find templates. Will be tried in order "
              "before the default FileSystem ones.",
@@ -185,7 +242,7 @@ class TemplateExporter(Exporter):
     def __init__(self, config=None, **kw):
         """
         Public constructor
-    
+
         Parameters
         ----------
         config : config
@@ -206,10 +263,17 @@ class TemplateExporter(Exporter):
 
     def _load_template(self):
         """Load the Jinja template object from the template file
-        
+
         This is triggered by various trait changes that would change the template.
         """
 
+        # this gives precedence to a raw_template if present
+        with self.hold_trait_notifications():
+            if self.template_file != self._raw_template_key:
+                self._last_template_file = self.template_file
+            if self.raw_template:
+                self.template_file = self._raw_template_key
+
         if not self.template_file:
             raise ValueError("No template_file specified!")
 
@@ -235,7 +299,19 @@ class TemplateExporter(Exporter):
         """
         nb_copy, resources = super(TemplateExporter, self).from_notebook_node(nb, resources, **kw)
         resources.setdefault('raw_mimetypes', self.raw_mimetypes)
+        resources['global_content_filter'] = {
+                'include_code': not self.exclude_code_cell,
+                'include_markdown': not self.exclude_markdown,
+                'include_raw': not self.exclude_raw,
+                'include_unknown': not self.exclude_unknown,
+                'include_input': not self.exclude_input,
+                'include_output': not self.exclude_output,
+                'include_input_prompt': not self.exclude_input_prompt,
+                'include_output_prompt': not self.exclude_output_prompt,
+                'no_prompt': self.exclude_input_prompt and self.exclude_output_prompt,
+                }
 
+        # Top level variables are passed to the template_exporter here.
         output = self.template.render(nb=nb_copy, resources=resources)
         return output, resources
 
@@ -321,7 +397,8 @@ class TemplateExporter(Exporter):
              os.path.join(here, self.template_skeleton_path)]
 
         loaders = self.extra_loaders + [
-            ExtensionTolerantLoader(FileSystemLoader(paths), self.template_extension)
+            ExtensionTolerantLoader(FileSystemLoader(paths), self.template_extension),
+            DictLoader({self._raw_template_key: self.raw_template})
         ]
         environment = Environment(
             loader=ChoiceLoader(loaders),
