@@ -9,11 +9,14 @@ import re
 
 from .base import ExportersTestsBase
 from ..latex import LatexExporter
+from ...tests.utils import onlyif_cmds_exist
+
+from traitlets.config import Config
 from nbformat import write
 from nbformat import v4
-from ipython_genutils.testing.decorators import onlyif_cmds_exist
 from testpath.tempdir import TemporaryDirectory
 
+from jinja2 import DictLoader
 
 class TestLatexExporter(ExportersTestsBase):
     """Contains test functions for latex.py"""
@@ -110,8 +113,37 @@ class TestLatexExporter(ExportersTestsBase):
         in_regex = r"In \[\{\\color\{incolor\}(.*)\}\]:"
         out_regex = r"Out\[\{\\color\{outcolor\}(.*)\}\]:"
 
-        ins = ["2", "10", " ", " ", "*", "0"]
+        ins = ["2", "10", " ", " ",  "0"]
         outs = ["10"]
 
         assert re.findall(in_regex, output) == ins
         assert re.findall(out_regex, output) == outs
+
+    @onlyif_cmds_exist('pandoc')
+    def test_no_prompt_yes_input(self):
+        no_prompt = {
+            "TemplateExporter":{
+                "exclude_input_prompt": True,
+                "exclude_output_prompt": True,
+            }
+        }
+        c_no_prompt = Config(no_prompt)
+
+        exporter = LatexExporter(config=c_no_prompt)
+        (output, resources) = exporter.from_filename(
+            self._get_notebook(nb_name="prompt_numbers.ipynb"))
+        assert "shape" in output
+        assert "evs" in output
+        
+    def test_in_memory_template_tplx(self):
+        # Loads in an in memory latex template (.tplx) using jinja2.DictLoader
+        # creates a class that uses this template with the template_file argument
+        # converts an empty notebook using this mechanism
+        my_loader_tplx = DictLoader({'my_template': "{%- extends 'article.tplx' -%}"})
+        
+        class MyExporter(LatexExporter):
+            template_file = 'my_template'
+
+        exporter = MyExporter(extra_loaders=[my_loader_tplx])
+        nb = v4.new_notebook()
+        out, resources = exporter.from_notebook_node(nb)
